pub struct ContainerMetadata {
pub version: Option<u16>,
pub ingest_settings: Option<IngestSettings>,
}Expand description
Metadata supplied with an item container containing trace metrics.
Versions
Behaviour
Different versions influence how trace metrics are normalized and processed:
| Version | client ip | user agent |
|---|---|---|
| none | {{auto}} | never |
| 2 | {{auto}}, settings | settings |
For example, in version 2:
- the client ip is inferred if either the client address attribute is
set to
{{auto}}or the ingest settings specifyinfer_ipasauto. - the user agent is only inferred if ingest settings specify
infer_user_agentasauto.
Schema Changelog
| Version | Changes |
|---|---|
| 2 | Adds ingest_settings |
Fields
version: Option<u16>The metadata version.
The version influences how trace metrics are processed during ingestion.
ingest_settings: Option<IngestSettings>Settings controlling parts of the ingestion of individual trace metrics.
Supported since version 2.